rpms/eclipse-cdt/devel eclipse-cdt-bug472731.patch, NONE, 1.1 eclipse-cdt-no-tests-5.0.1.patch, NONE, 1.1 .cvsignore, 1.40, 1.41 eclipse-cdt.spec, 1.115, 1.116 fetch-cdt.sh, 1.3, 1.4 sources, 1.49, 1.50

Jeff Johnston jjohnstn at fedoraproject.org
Fri Nov 28 21:40:35 UTC 2008


Author: jjohnstn

Update of /cvs/extras/rpms/eclipse-cdt/devel
In directory cvs1.fedora.phx.redhat.com:/tmp/cvs-serv12009

Modified Files:
	.cvsignore eclipse-cdt.spec fetch-cdt.sh sources 
Added Files:
	eclipse-cdt-bug472731.patch eclipse-cdt-no-tests-5.0.1.patch 
Log Message:

* Fri Nov 28 2008 Jeff Johnston <jjohnstn at redhat.com> 5.0.1-1
- Rebase to CDT 5.0.1.
- Fix bug in autotools project type detection.
- Resolve #472731



eclipse-cdt-bug472731.patch:

--- NEW FILE eclipse-cdt-bug472731.patch ---
diff -up ./org.eclipse.linuxtools.cdt.autotools/src/org/eclipse/linuxtools/cdt/autotools/AutotoolsMakefileBuilder.java.fix ./org.eclipse.linuxtools.cdt.autotools/src/org/eclipse/linuxtools/cdt/autotools/AutotoolsMakefileBuilder.java
--- ./org.eclipse.linuxtools.cdt.autotools/src/org/eclipse/linuxtools/cdt/autotools/AutotoolsMakefileBuilder.java.fix	2008-11-28 15:52:21.000000000 -0500
+++ ./org.eclipse.linuxtools.cdt.autotools/src/org/eclipse/linuxtools/cdt/autotools/AutotoolsMakefileBuilder.java	2008-11-28 15:52:50.000000000 -0500
@@ -21,6 +21,7 @@ import org.eclipse.cdt.core.resources.IC
 import org.eclipse.cdt.managedbuilder.core.IBuilder;
 import org.eclipse.cdt.managedbuilder.core.IConfiguration;
 import org.eclipse.cdt.managedbuilder.core.IManagedBuildInfo;
+import org.eclipse.cdt.managedbuilder.core.IManagedProject;
 import org.eclipse.cdt.managedbuilder.core.ManagedBuildManager;
 import org.eclipse.cdt.managedbuilder.core.ManagedBuilderCorePlugin;
 import org.eclipse.cdt.managedbuilder.core.ManagedCProjectNature;
@@ -77,7 +78,8 @@ public class AutotoolsMakefileBuilder ex
 			// then return true.
 			if (project.getNature(ManagedCProjectNature.MNG_NATURE_ID) != null) {
 				IManagedBuildInfo info = ManagedBuildManager.getBuildInfo(project);
-				if (info.getManagedProject().getProjectType().getId().equals(AUTOTOOLS_PROJECT_TYPE_ID)) {
+				IManagedProject m = info.getManagedProject();
+				if (m != null && m.getProjectType().getId().equals(AUTOTOOLS_PROJECT_TYPE_ID)) {
 					AutotoolsProjectNature.addAutotoolsBuilder(project, new NullProgressMonitor());
 					AutotoolsPlugin.verifyScannerInfoProvider(project);
 					return true;
@@ -85,7 +87,9 @@ public class AutotoolsMakefileBuilder ex
 			}
 		} catch (CoreException e) {
 			// Don't care...fall through to not found.
-		} 
+		} catch (Exception f) {
+			// Don't care...fall through to not found.
+		}
 		// Otherwise not found.
 		return false;
 	}

eclipse-cdt-no-tests-5.0.1.patch:

--- NEW FILE eclipse-cdt-no-tests-5.0.1.patch ---
diff -up ./org.eclipse.cdt.releng/build.xml.notests ./org.eclipse.cdt.releng/build.xml
--- ./org.eclipse.cdt.releng/build.xml.notests	2008-07-31 20:34:19.000000000 -0400
+++ ./org.eclipse.cdt.releng/build.xml	2008-07-31 20:41:49.000000000 -0400
@@ -4,7 +4,7 @@
 		<echo message="${eclipse.home}"/>
 	</target>
 	
-	<target name="build" depends="zips,test"/>
+	<target name="build" depends="zips"/>
 	<target name="nightly" depends="tag,zips,sign,test,copy"/>
 	<target name="testbuild" depends="zips,test,copy"/>
 	<target name="buildcopy" depends="zips,copy"/>


Index: .cvsignore
===================================================================
RCS file: /cvs/extras/rpms/eclipse-cdt/devel/.cvsignore,v
retrieving revision 1.40
retrieving revision 1.41
diff -u -r1.40 -r1.41
--- .cvsignore	6 Nov 2008 23:57:20 -0000	1.40
+++ .cvsignore	28 Nov 2008 21:40:05 -0000	1.41
@@ -19,3 +19,4 @@
 eclipse-cdt-fetched-src-libhover-1_0_0.tar.gz
 eclipse-cdt-fetched-src-autotools-20081106.tar.gz
 eclipse-cdt-fetched-src-libhover-20081106.tar.gz
+eclipse-cdt-fetched-src-CDT_5_0_1.tar.bz2


Index: eclipse-cdt.spec
===================================================================
RCS file: /cvs/extras/rpms/eclipse-cdt/devel/eclipse-cdt.spec,v
retrieving revision 1.115
retrieving revision 1.116
diff -u -r1.115 -r1.116
--- eclipse-cdt.spec	17 Nov 2008 23:32:38 -0000	1.115
+++ eclipse-cdt.spec	28 Nov 2008 21:40:05 -0000	1.116
@@ -6,9 +6,9 @@
 %define major                   5
 %define minor                   0       
 %define majmin                  %{major}.%{minor}
-%define micro                   0
+%define micro                   1
 %define eclipse_base            %{_libdir}/eclipse
-%define build_id		200806171202
+%define build_id		200809190802
 
 # All arches line up except i386 -> x86
 %ifarch %{ix86}
@@ -20,7 +20,7 @@
 Summary:        Eclipse C/C++ Development Tools (CDT) plugin
 Name:           eclipse-cdt
 Version:        %{majmin}.%{micro}
-Release:        12%{?dist}
+Release:        1%{?dist}
 License:        EPL and CPL
 Group:          Development/Tools
 URL:            http://www.eclipse.org/cdt
@@ -31,7 +31,7 @@
 # script.  Note that the optional c99 and upc parsers plus the optional
 # xlc support features have been removed.
 
-Source0: %{name}-fetched-src-CDT_5_0_0.tar.bz2
+Source0: %{name}-fetched-src-CDT_5_0_1.tar.bz2
 Source4: fetch-cdt.sh
 
 Source1: http://sources.redhat.com/eclipse/autotools/eclipse-cdt-fetched-src-autotools-20081106.tar.gz
@@ -97,6 +97,10 @@
 # the .cproject file.  This patch prevents the problem.
 Patch16: %{name}-managedConfigurations-fix.patch
 
+# Patch to autotools project detector code to not assume that ManagedProject
+# exists if project has Managed Nature.
+Patch17: %{name}-bug472731.patch
+
 BuildRequires: eclipse-pde
 BuildRequires: eclipse-mylyn >= 3.0
 %if %{gcj_support}
@@ -227,6 +231,7 @@
 mkdir autotools
 pushd autotools
 tar -xzf %{SOURCE1}
+%patch17
 popd
 
 ## Libhover stuff
@@ -570,6 +575,11 @@
 %endif
 
 %changelog
+* Fri Nov 28 2008 Jeff Johnston <jjohnstn at redhat.com> 5.0.1-1
+- Rebase to CDT 5.0.1.
+- Fix bug in autotools project type detection.
+- Resolve #472731
+
 * Mon Nov 17 2008 Jeff Johnston <jjohnstn at redhat.com> 5.0.0-12
 - Fix typo in autotools and libhover sources tarballs.
 - Remove redundant patches which are already in new tarballs.


Index: sources
===================================================================
RCS file: /cvs/extras/rpms/eclipse-cdt/devel/sources,v
retrieving revision 1.49
retrieving revision 1.50
diff -u -r1.49 -r1.50
--- sources	6 Nov 2008 23:57:20 -0000	1.49
+++ sources	28 Nov 2008 21:40:05 -0000	1.50
@@ -1,5 +1,5 @@
 5c470fb0777d27541edbfa31443d91f7  eclipse-cdt-cppunit-20061102.tar.gz
 2d4ae0a2131ba1efc896d981072cc091  eclipse-cdt-target_filter.gif.gz
-8958a138a5d96c9c1fa892e895b29bcd  eclipse-cdt-fetched-src-CDT_5_0_0.tar.bz2
 7bdfc7cfe88e694903225a858d3442c3  eclipse-cdt-fetched-src-autotools-20081106.tar.gz
 621bd568fed245c8368819692a066be9  eclipse-cdt-fetched-src-libhover-20081106.tar.gz
+f0db116442be6f461611739308535175  eclipse-cdt-fetched-src-CDT_5_0_1.tar.bz2




More information about the scm-commits mailing list
Index: fetch-cdt.sh
===================================================================
RCS file: /cvs/extras/rpms/eclipse-cdt/devel/fetch-cdt.sh,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- fetch-cdt.sh	27 Aug 2008 20:14:42 -0000	1.3
+++ fetch-cdt.sh	28 Nov 2008 21:40:05 -0000	1.4
@@ -1,6 +1,6 @@
 #!/bin/sh
 
-CDTTAG=CDT_5_0_0
+CDTTAG=CDT_5_0_1
 ECLIPSEBASE=$(rpm --eval %{_libdir})/eclipse
 
 mkdir -p temp && cd temp
@@ -17,7 +17,7 @@
 sed --in-place -e'69,69i\\t\t<ant antfile="build.xml" dir="${pde.build.scripts}" target="preBuild">\n\t\t\t<property name="builder" value="${basedir}/testing"/>\n\t\t</ant>' build.xml
 
 # Remove copying of binary jar in build.xml.  We remove this jar so this operation will fail.
-sed --in-place -e'143,145d' build.xml
+sed --in-place -e "/copy file=\"\${buildDirectory}.*net\.sourceforge\.lpg/,/\/>/"d build.xml 
 
 PDEBUILDVERSION=$(ls $ECLIPSEBASE/dropins/sdk/plugins | grep pde.build_ | sed 's/org.eclipse.pde.build_//')
 java -cp /usr/lib/eclipse/startup.jar \
@@ -33,7 +33,7 @@
   -Dpde.build.scripts=$ECLIPSEBASE/dropins/sdk/plugins/org.eclipse.pde.build_$PDEBUILDVERSION/scripts \
   -DcdtTag=$CDTTAG \
   -DdontUnzip=true fetch
-eclipse -nosplash -console
+#eclipse -nosplash -console
 
 find . -name net.*.jar -exec rm {} \;
 
@@ -43,16 +43,21 @@
 pushd results/features
 rm -rf *c99*
 rm -rf *upc*
+rm -rf *lrparser*
+rm -rf *xlc*
 popd
 pushd results/plugins
 rm -rf *c99*
 rm -rf *upc*
+rm -rf *lrparser*
+rm -rf *xlc*
 popd
 
 # Remove optional features: c99, upc, and xlc from the master feature list.  We do not package them.
 pushd results/features/org.eclipse.cdt.master
 sed --in-place -e "56,63d" feature.xml
-sed --in-place -e "40,43d" feature.xml
+sed --in-place -e "36,43d" feature.xml
 popd
 
 cd .. && tar jcf eclipse-cdt-fetched-src-$CDTTAG.tar.bz2 org.eclipse.cdt.releng
@@ -43,16 +43,21 @@
 popd
 
-# Remove optional features: c99, upc, and xlc from the master feature list.  We do not package them.
+# Remove optional features: c99, upc, lrparser, and xlc from the master 
+# feature list.  We do not package them.
 pushd results/features/org.eclipse.cdt.master
 sed --in-place -e "56,63d" feature.xml

